
##<a href=#intro>What IS goulash?</a>

It's sort of like soup, but more viscous, and as for what is actually inside
the truth is that no one really knows.  Likewise for this library.  Random odds
and ends, common tools and patterns shared by my other projects.  See the autogenerated docs [here](http://mattvonrocketstein.github.io/goulash).


## <a href=#installation>Installing goulash</a>

Install with pypi:

```shell
   $ pip install goulash
```

Or try the bleeding edge:

```shell
   $ git clone https://github.com/mattvonrocketstein/goulash.git
   $ cd goulash
   $ virtualenv venv
   $ source venv/bin/activate
   $ python setup.py develop
```

You can find the primary documentation and API reference [here](http://mattvonrocketstein.github.io/goulash/).
